import request from "@/utils/request";
//学习内容-新增-修改
export function studyEdit(data) {
  return request({
    url: "/admin/st/study/edit",
    method: "post",
    data,
  });
}
//学习内容-列表分页
export function studyDetPageList(data) {
  return request({
    url: "/admin/st/study/getPageList",
    method: "post",
    data,
  });
}
//学习内容-删除
export function studyDelete(stStudyContentId) {
  return request({
    url: "/admin/st/study/delete",
    method: "get",
    params: { stStudyContentId },
  });
}
//题库-新增-修改
export function topicBankEdit(data) {
  return request({
    url: "/admin/st/topicBank/edit",
    method: "post",
    data,
  });
}
//题库-列表分页
export function topicBankGetPageList(data) {
  return request({
    url: "/admin/st/topicBank/getPageList",
    method: "post",
    data,
  });
}
//题库-删除
export function topicBankDelete(stTopicBankId) {
  return request({
    url: "/admin/st/topicBank/delete",
    method: "get",
    params: { stTopicBankId },
  });
}
//题目-新增-修改
export function topicEdit(data) {
  return request({
    url: "/admin/st/topic/edit",
    method: "post",
    data,
  });
}
//题目-列表分页
export function topicgetPageList(data) {
  return request({
    url: "/admin/st/topic/getPageList",
    method: "post",
    data,
  });
}
//题目-删除
export function topicDelete(stTopicId) {
  return request({
    url: "/admin/st/topic/delete",
    method: "get",
    params: { stTopicId },
  });
}
//试卷-题库列表
export function paperTopicBankList() {
  return request({
    url: "/admin/st/paper/topicBankList",
    method: "get",
    params: {},
  });
}
//试卷-题目列表
export function paperTopicList(stTopicBankId) {
  return request({
    url: "/admin/st/paper/topicList",
    method: "get",
    params: { stTopicBankId },
  });
}
//试卷-新增-修改
export function paperEdit(data) {
  return request({
    url: "/admin/st/paper/edit",
    method: "post",
    data,
  });
}
//试卷-列表分页
export function paperGetPageList(data) {
  return request({
    url: "/admin/st/paper/getPageList",
    method: "post",
    data,
  });
}
//试卷-删除
export function paperDelete(stPaperId) {
  return request({
    url: "/admin/st/paper/delete",
    method: "get",
    params: { stPaperId },
  });
}
//试卷-学习内容列表
export function stareaStudyList() {
  return request({
    url: "/admin/st/starea/studyList",
    method: "get",
    params: {},
  });
}
//试卷-试卷列表
export function stareaPaperList() {
  return request({
    url: "/admin/st/starea/paperList",
    method: "get",
    params: {},
  });
}
//通行区域绑定-绑定学习
export function stareaBingdingStudy(data) {
  return request({
    url: "/admin/st/starea/bingdingStudy",
    method: "post",
    data,
  });
}
//通行区域绑定-绑定试卷
export function stareaBingdingPaper(data) {
  return request({
    url: "/admin/st/starea/bingdingPaper",
    method: "post",
    data,
  });
}
//通行区域绑定-列表分页
export function stareaGetList() {
  return request({
    url: "/admin/st/starea/getList",
    method: "get",
    params: {},
  });
}
//监管人员-新增
export function invigilateInsert(data) {
  return request({
    url: "/admin/st/invigilate/insert",
    method: "post",
    data,
  });
}
//监管人员-列表分页
export function invigilateGetPageList(data) {
  return request({
    url: "/admin/st/invigilate/getPageList",
    method: "post",
    data,
  });
}
//监管人员-删除
export function invigilateDel(tInvigilateUserId) {
  return request({
    url: "/admin/st/invigilate/delete",
    method: "get",
    params: { tInvigilateUserId },
  });
}
